package com.chenyang.nse.bussiness.service.core;

import com.chenyang.nse.bussiness.dao.PageInfo;
import com.chenyang.nse.bussiness.engine.infa.InfoProperty;
import com.chenyang.nse.bussiness.entity.orm.table.core.desensitizationselftask.DesensitizationSelfTask;
import com.chenyang.nse.bussiness.entity.orm.table.core.desensitizationtask.DesensitizationFile;
import com.chenyang.nse.bussiness.entity.orm.table.core.desensitizationtask.DesensitizationTable;
import com.chenyang.nse.bussiness.entity.orm.table.core.desensitizationtask.DesensitizationTablecolumn;
import com.chenyang.nse.bussiness.entity.orm.table.core.desensitizationtask.Desensitizationsource;
import com.chenyang.nse.bussiness.entity.orm.table.core.desensitizationtask.Desensitizationtarget;
import com.chenyang.nse.bussiness.entity.orm.table.core.temporary.TCoreMonitorTemporary;
import com.chenyang.nse.bussiness.thread.ExecuteParam;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;

public interface DesensitizationselftaskService {
   List<DesensitizationSelfTask> queryTask(String projectid, String taskname, PageInfo pageInfo);

   void updateTask(DesensitizationSelfTask desensitizationSelfTask);

   String gettaskBytasknamereal(String tasknamereal, String projectId);

   DesensitizationSelfTask savetask_info(String tasknamereal, Map<String, Object> map);

   boolean generate_xml(Map map, HttpServletRequest request) throws Exception;

   Desensitizationsource querySourceInfo(String taskid);

   Desensitizationtarget queryTargetInfo(String taskid);

   List<DesensitizationTable> queryTableList(String taskid);

   DesensitizationTable queryTableByTableName(String taskid, String tableName);

   DesensitizationSelfTask queryTaskById(String taskid);

   DesensitizationSelfTask queryTaskByName(String taskname, String projectid);

   void removeTask(String taskid);

   Desensitizationtarget queryTargetById(String taskid);

   InfoProperty getInfoProperty();

   List<DesensitizationSelfTask> queryTaskList(String taskid);

   void executeDB_pwc_FILE_batchwrite_DB(ExecuteParam executeParam) throws Exception;

   void executeFILE_pwc_FILE_batchwrite_DB(ExecuteParam executeParam) throws Exception;

   void executeDB_batchread_FILE_pwc_FILE_batchwrite_DB(ExecuteParam executeParam) throws Exception;

   void executeDB_batchread_FILE_pwc_FILE(ExecuteParam executeParam) throws Exception;

   void executeDB_batchread_FILE_pwc_DB(ExecuteParam executeParam) throws Exception;

   void executeTask(ExecuteParam executeParam) throws Exception;

   void executeTaskNormal(ExecuteParam executeParam) throws Exception;

   List<DesensitizationSelfTask> queryTaskAll();

   long getExeTaskNum();

   long getTableNum(String taskid);

   int saveDesensitizationMonitor(StringBuilder sql);

   long getTableNumByAll(String sql);

   DesensitizationFile queryDesensitizationfileBytaskid(String taskid);

   List<DesensitizationTablecolumn> queryColumInfo(String taskid, String table);

   List<DesensitizationSelfTask> queryTaskByPage(PageInfo pageInfo);

   DesensitizationSelfTask saveSameDBtask_info1(String tasknamereal, Map<String, Object> map);

   DesensitizationSelfTask saveSameDBtask_info2(String tasknamereal, Map<String, Object> map);

   List<DesensitizationSelfTask> saveSameDBtask_info(String tasknamereal, Map<String, Object> map);

   List<Desensitizationsource> queryAllSourceInfo(String taskid);

   void createMonitor(ExecuteParam executeParam, String tableName, Map<String, String> tableMap);

   List<DesensitizationSelfTask> queryTaskAllbyprojectid(String projectid);

   TCoreMonitorTemporary getMoniterBytaskid(String taskid);

   DesensitizationSelfTask queryTaskById1(String taskid);

   String getTasknamereal(String taskid);
}
